@@ -17,6 +17,8 @@
 #' @param p_name Name given to p-value estimate
 #' @param digits Number of digits to round to (1) estimate, (2) confidence
 #'   interval limits, (3) p-value.
+#' @param exp Currently GLM only. Exponentiate coefficients and confidence
+#'   intervals. Defaults to TRUE.
 #' @param confint_type One of \code{c("profile", "default")} for GLM models
 #'   (\code{\link[MASS]{confint.glm}}) or \code{c("profile", "Wald", "boot")}
 #'   for \code{glmer/lmer} models (\code{\link[lme4]{confint.merMod}}.). Not
@@ -31,7 +33,7 @@
 #'   list of two dataframes, one is model parameters, one is model metrics.
 #'   length two
 #'
-#' @family \code{finalfit} model extractors
+#' @family finalfit model extractors
 #'
 #' @export
 #'
@@ -50,8 +52,8 @@
 #' explanatory = c("age.factor", "sex.factor", "obstruct.factor", "perfor.factor")
 #' dependent = "mort_5yr"
 #' colon_s %>%
-#' 	glmmulti(dependent, explanatory) %>%
-#' 	fit2df(estimate_suffix=" (univariable)")
+#'   glmmulti(dependent, explanatory) %>%
+#'   fit2df(estimate_suffix=" (univariable)")
 #'
 #' # glmerMod
 #' explanatory = c("age.factor", "sex.factor", "obstruct.factor", "perfor.factor")
@@ -59,15 +61,15 @@
 #' dependent = "mort_5yr"
 #' colon_s %>%
 #'   glmmixed(dependent, explanatory, random_effect) %>%
-#' 	 fit2df(estimate_suffix=" (multilevel)")
+#'   fit2df(estimate_suffix=" (multilevel)")
 #'
 #' # glmboot
 #' ## Note number of draws set to 100 just for speed in this example
 #' explanatory = c("age.factor", "sex.factor", "obstruct.factor", "perfor.factor")
 #' dependent = "mort_5yr"
 #' colon_s %>%
-#' 	glmmulti_boot(dependent, explanatory,  R = 100) %>%
-#' 	fit2df(estimate_suffix=" (multivariable (BS CIs))")
+#'   glmmulti_boot(dependent, explanatory,  R = 100) %>%
+#'   fit2df(estimate_suffix=" (multivariable (BS CIs))")
 #'
 #' # lm
 #' fit = lm(nodes ~  age.factor + sex.factor + obstruct.factor + perfor.factor,
@@ -82,26 +84,49 @@
 #'
 #' colon_s %>%
 #'   lmmixed(dependent, explanatory, random_effect) %>%
-#' 	 fit2df(estimate_suffix=" (multilevel")
+#'   fit2df(estimate_suffix=" (multilevel")
 #'
 #' # coxphlist
 #' explanatory = c("age.factor", "sex.factor", "obstruct.factor", "perfor.factor")
 #' dependent = "Surv(time, status)"
 #'
 #' colon_s %>%
-#' 	coxphuni(dependent, explanatory) %>%
-#' 	fit2df(estimate_suffix=" (univariable)")
+#'   coxphuni(dependent, explanatory) %>%
+#'   fit2df(estimate_suffix=" (univariable)")
 #'
 #' colon_s %>%
-#' 	coxphmulti(dependent, explanatory) %>%
-#' 	fit2df(estimate_suffix=" (multivariable)")
+#'   coxphmulti(dependent, explanatory) %>%
+#'   fit2df(estimate_suffix=" (multivariable)")
 #'
 #' # coxph
 #' fit = coxph(Surv(time, status) ~ age.factor + sex.factor + obstruct.factor + perfor.factor,
 #'   data = colon_s)
 #'
 #' fit %>%
-#' 	fit2df(estimate_suffix=" (multivariable)")
+#'   fit2df(estimate_suffix=" (multivariable)")
+#' 	
+#' # crr: competing risks
+#' melanoma = boot::melanoma
+#' melanoma = melanoma %>% 
+#'   mutate(
+#'     status_crr = ifelse(status == 2, 0, # "still alive"
+#'       ifelse(status == 1, 1, # "died of melanoma"
+#'       2)), # "died of other causes" 
+#'     sex = factor(sex),
+#'     ulcer = factor(ulcer)
+#'   )
+#'
+#' dependent = c("Surv(time, status_crr)")
+#' explanatory = c("sex", "age", "ulcer")
+#' melanoma %>% 
+#'   summary_factorlist(dependent, explanatory, column = TRUE, fit_id = TRUE) %>% 
+#'   ff_merge(
+#'     melanoma %>% 
+#'       crrmulti(dependent, explanatory) %>% 
+#'       fit2df(estimate_suffix = " (competing risks)")
+#'   ) %>% 
+#' select(-fit_id, -index) %>% 
+#' dependent_label(melanoma, dependent)
 
 fit2df <- function(...){
 	UseMethod("fit2df")
@@ -126,21 +151,21 @@ fit2df.lm <- function(.data, condense=TRUE, metrics=FALSE, remove_intercept=TRUE
 											digits=c(2,2,3),
 											confint_level = 0.95,
 											confint_sep = " to ", ...){
-
+	
 	df.out = extract_fit(.data=.data, explanatory_name=explanatory_name,
 											 estimate_name=estimate_name, estimate_suffix=estimate_suffix,
 											 p_name=p_name, digits=digits,)
-
+	
 	if (condense==TRUE){
 		df.out = condense_fit(df.out, explanatory_name=explanatory_name,
 													estimate_name=estimate_name, estimate_suffix=estimate_suffix,
 													p_name=p_name, digits=digits, confint_sep=confint_sep)
 	}
-
+	
 	if (remove_intercept==TRUE){
 		df.out = remove_intercept(df.out)
 	}
-
+	
 	# Extract model metrics
 	if (metrics==TRUE){
 		metrics.out = ff_metrics(.data)
@@ -167,26 +192,26 @@ fit2df.lmlist <- function(.data, condense=TRUE, metrics=FALSE, remove_intercept=
 													p_name = "p", digits=c(2,2,3),
 													confint_level = 0.95,
 													confint_sep = " to ", ...){
-
+	
 	if (metrics==TRUE && length(.data)>1){
 		stop("Metrics only generated for single models: multiple models supplied to function")
 	}
-
+	
 	df.out = .data %>% 
 		purrr::map_dfr(extract_fit, explanatory_name=explanatory_name,
-											 estimate_name=estimate_name, estimate_suffix=estimate_suffix,
-											 p_name=p_name,  confint_level=confint_level)
-
+									 estimate_name=estimate_name, estimate_suffix=estimate_suffix,
+									 p_name=p_name,  confint_level=confint_level)
+	
 	if (condense==TRUE){
 		df.out = condense_fit(df.out, explanatory_name=explanatory_name,
 													estimate_name=estimate_name, estimate_suffix=estimate_suffix,
 													p_name=p_name, digits=digits, confint_sep=confint_sep)
 	}
-
+	
 	if (remove_intercept==TRUE){
 		df.out = remove_intercept(df.out)
 	}
-
+	
 	# Extract model metrics
 	if (metrics==TRUE){
 		metrics.out = ff_metrics(.data)
@@ -214,26 +239,28 @@ fit2df.glm <- function(.data, condense=TRUE, metrics=FALSE, remove_intercept=TRU
 											 estimate_suffix = "",
 											 p_name = "p",
 											 digits=c(2,2,3),
+											 exp = TRUE,
 											 confint_type = "profile",
 											 confint_level = 0.95,
 											 confint_sep = "-", ...){
-
-	df.out = extract_fit(.data=.data, explanatory_name=explanatory_name,
-											 estimate_name=estimate_name, estimate_suffix=estimate_suffix,
+	
+	df.out = extract_fit(.data = .data, explanatory_name = explanatory_name,
+											 estimate_name = estimate_name, estimate_suffix = estimate_suffix,
+											 exp = exp, 
 											 confint_type = confint_type,
 											 confint_level = confint_level,
 											 p_name=p_name)
-
+	
 	if (condense==TRUE){
-		df.out = condense_fit(df.out, explanatory_name=explanatory_name,
-													estimate_name=estimate_name, estimate_suffix=estimate_suffix,
-													p_name=p_name, digits=digits, confint_sep=confint_sep)
+		df.out = condense_fit(df.out, explanatory_name = explanatory_name,
+													estimate_name = estimate_name, estimate_suffix = estimate_suffix,
+													p_name = p_name, digits = digits, confint_sep = confint_sep)
 	}
-
+	
 	if (remove_intercept==TRUE){
 		df.out = remove_intercept(df.out)
 	}
-
+	
 	# Extract model metrics
 	if (metrics==TRUE){
 		metrics.out = ff_metrics(.data)
@@ -259,14 +286,14 @@ fit2df.glmboot = function(.data, condense=TRUE, metrics=FALSE, remove_intercept=
 													digits=c(2,2,3),
 													confint_sep = "-", ...){
 	if(metrics == TRUE) warning("Metrics not currently available for this model")
-
+	
 	x = .data
 	d.estimate = digits[1]
 	d.confint = digits[2]
 	d.p = digits[3]
-
+	
 	R = dim(x$t)[1]
-
+	
 	df.out = data.frame(
 		explanatory = names(x$t0),
 		estimate = exp(x$t0))
@@ -280,17 +307,17 @@ fit2df.glmboot = function(.data, condense=TRUE, metrics=FALSE, remove_intercept=
 	df.out$U95 = round(df.out$U95, d.confint)
 	df.out$p = round(df.out$p, d.p)
 	colnames(df.out) = c(explanatory_name, paste0(estimate_name, estimate_suffix), "L95", "U95", p_name)
-
+	
 	if (condense==TRUE){
 		df.out = condense_fit(df.out, explanatory_name=explanatory_name,
 													estimate_name=estimate_name, estimate_suffix=estimate_suffix,
 													p_name=p_name, digits=digits, confint_sep=confint_sep)
 	}
-
+	
 	if (remove_intercept==TRUE){
 		df.out = remove_intercept(df.out)
 	}
-
+	
 	return(df.out)
 }
 
@@ -308,31 +335,84 @@ fit2df.glmlist <- function(.data, condense=TRUE, metrics=FALSE, remove_intercept
 													 estimate_suffix = "",
 													 p_name = "p",
 													 digits=c(2,2,3),
+													 exp = TRUE, 
 													 confint_type = "profile",
 													 confint_level = 0.95,
 													 confint_sep = "-", ...){
-
+	
 	if (metrics==TRUE && length(.data)>1){
 		stop("Metrics only generated for single models: multiple models supplied to function")
 	}
-
+	
 	df.out = .data %>% 
-		purrr::map_dfr(extract_fit, explanatory_name=explanatory_name,
-											 estimate_name=estimate_name, estimate_suffix=estimate_suffix,
-											 p_name=p_name, confint_type = confint_type,
-											 confint_level = confint_level,
-											 digits=digits)
+		purrr::map_dfr(extract_fit, explanatory_name = explanatory_name,
+									 estimate_name = estimate_name, estimate_suffix = estimate_suffix,
+									 p_name = p_name, exp = exp, 
+									 confint_type = confint_type,
+									 confint_level = confint_level,
+									 digits=digits)
+	
+	if (condense == TRUE){
+		df.out = condense_fit(.data=df.out, explanatory_name=explanatory_name,
+													estimate_name=estimate_name, estimate_suffix=estimate_suffix,
+													p_name=p_name, digits=digits, confint_sep=confint_sep)
+	}
+	
+	if (remove_intercept == TRUE){
+		df.out = remove_intercept(df.out)
+	}
+	
+	# Extract model metrics
+	if (metrics == TRUE){
+		metrics.out = ff_metrics(.data)
+		return(list(df.out, metrics.out))
+	} else {
+		return(df.out)
+	}
+}
 
+
+#' Extract \code{svyglmuni} and \code{svyglmmulti} model fit results to dataframe: \code{finalfit} model extracters
+#'
+#' \code{fit2df.svyglmlist} is the model extract method for \code{svyglmuni} and \code{svyglmmulti}.
+#'
+#' @rdname fit2df
+#' @method fit2df svyglmlist
+#' @export
+
+fit2df.svyglmlist <- function(.data, condense=TRUE, metrics=FALSE, remove_intercept=TRUE,
+													 explanatory_name = "explanatory",
+													 estimate_name = "Coefficient",
+													 estimate_suffix = "",
+													 p_name = "p",
+													 digits=c(2,2,3),
+													 exp = FALSE, 
+													 confint_type = "profile",
+													 confint_level = 0.95,
+													 confint_sep = "-", ...){
+	
+	if (metrics==TRUE && length(.data)>1){
+		stop("Metrics only generated for single models: multiple models supplied to function")
+	}
+	
+	df.out = .data %>% 
+		purrr::map_dfr(extract_fit, explanatory_name = explanatory_name,
+									 estimate_name = estimate_name, estimate_suffix = estimate_suffix,
+									 p_name = p_name, exp = exp, 
+									 confint_type = confint_type,
+									 confint_level = confint_level,
+									 digits=digits)
+	
 	if (condense==TRUE){
 		df.out = condense_fit(.data=df.out, explanatory_name=explanatory_name,
 													estimate_name=estimate_name, estimate_suffix=estimate_suffix,
 													p_name=p_name, digits=digits, confint_sep=confint_sep)
 	}
-
+	
 	if (remove_intercept==TRUE){
 		df.out = remove_intercept(df.out)
 	}
-
+	
 	# Extract model metrics
 	if (metrics==TRUE){
 		metrics.out = ff_metrics(.data)
@@ -342,6 +422,7 @@ fit2df.glmlist <- function(.data, condense=TRUE, metrics=FALSE, remove_intercept
 	}
 }
 
+
 #' Extract \code{lmerMod} model fit results to dataframe: \code{finalfit} model
 #' extracters
 #'
@@ -362,21 +443,21 @@ fit2df.lmerMod = function(.data, condense=TRUE, metrics=FALSE, remove_intercept=
 													confint_type = "Wald",
 													confint_level = 0.95,
 													confint_sep = "-", ...){
-
+	
 	df.out = extract_fit(.data=.data, explanatory_name=explanatory_name,
 											 estimate_name=estimate_name, estimate_suffix=estimate_suffix,
 											 p_name=p_name, confint_type = confint_type, confint_level = confint_level)
-
+	
 	if (condense==TRUE){
 		df.out = condense_fit(df.out, explanatory_name=explanatory_name,
 													estimate_name=estimate_name, estimate_suffix=estimate_suffix,
 													p_name=p_name, digits=digits, confint_sep=confint_sep)
 	}
-
+	
 	if (remove_intercept==TRUE){
 		df.out = remove_intercept(df.out)
 	}
-
+	
 	# Extract model metrics
 	if (metrics==TRUE){
 		metrics.out = ff_metrics(.data)
@@ -406,23 +487,23 @@ fit2df.glmerMod = function(.data, condense=TRUE, metrics=FALSE, remove_intercept
 													 confint_type = "Wald",
 													 confint_level = 0.95,
 													 confint_sep = "-", ...){
-
+	
 	df.out = extract_fit(.data=.data, explanatory_name=explanatory_name,
 											 estimate_name=estimate_name, estimate_suffix=estimate_suffix,
 											 p_name=p_name, confint_type = confint_type,
 											 confint_level = confint_level)
-
+	
 	if (condense==TRUE){
 		df.out = condense_fit(df.out, explanatory_name=explanatory_name,
 													estimate_name=estimate_name, estimate_suffix=estimate_suffix,
 													p_name=p_name, digits=digits, confint_sep=confint_sep)
 	}
-
+	
 	if (remove_intercept==TRUE){
 		df.out = remove_intercept(df.out)
 	}
-
-
+	
+	
 	# Extract model metrics
 	if (metrics==TRUE){
 		metrics.out = ff_metrics(.data)
@@ -440,18 +521,18 @@ fit2df.glmerMod = function(.data, condense=TRUE, metrics=FALSE, remove_intercept
 #' @method fit2df coxph
 #' @export
 #'
-fit2df.coxph <- function(.data, condense=TRUE, metrics=FALSE, remove_intercept=TRUE,
+fit2df.coxph <- function(.data, condense=TRUE, metrics=FALSE,
 												 explanatory_name = "explanatory",
 												 estimate_name = "HR",
 												 estimate_suffix = "",
 												 p_name = "p",
 												 digits=c(2,2,3),
 												 confint_sep = "-", ...){
-
+	
 	df.out = extract_fit(.data=.data, explanatory_name=explanatory_name,
 											 estimate_name=estimate_name, estimate_suffix=estimate_suffix,
 											 p_name=p_name)
-
+	
 	if (condense==TRUE){
 		df.out = condense_fit(.data=df.out, explanatory_name=explanatory_name,
 													estimate_name=estimate_name, estimate_suffix=estimate_suffix,
@@ -474,7 +555,7 @@ fit2df.coxph <- function(.data, condense=TRUE, metrics=FALSE, remove_intercept=T
 #' @method fit2df coxphlist
 #' @export
 
-fit2df.coxphlist <- function(.data, condense=TRUE, metrics=FALSE, remove_intercept=TRUE,
+fit2df.coxphlist <- function(.data, condense=TRUE, metrics=FALSE,
 														 explanatory_name = "explanatory",
 														 estimate_name = "HR",
 														 estimate_suffix = "",
@@ -482,18 +563,18 @@ fit2df.coxphlist <- function(.data, condense=TRUE, metrics=FALSE, remove_interce
 														 digits=c(2,2,3),
 														 confint_sep = "-", ...){
 	#if(metrics==TRUE) warning("Metrics not currently available for this model")
-
+	
 	df.out = .data %>% 
 		purrr::map_dfr(extract_fit, explanatory_name=explanatory_name,
-											 estimate_name=estimate_name, estimate_suffix=estimate_suffix,
-											 p_name=p_name, digits=digits)
-
+									 estimate_name=estimate_name, estimate_suffix=estimate_suffix,
+									 p_name=p_name, digits=digits)
+	
 	if (condense==TRUE){
 		df.out = condense_fit(.data=df.out, explanatory_name=explanatory_name,
 													estimate_name=estimate_name, estimate_suffix=estimate_suffix,
 													p_name=p_name, digits=digits, confint_sep=confint_sep)
 	}
-
+	
 	# Extract model metrics
 	if (metrics==TRUE){
 		metrics.out = ff_metrics(.data)
@@ -504,65 +585,137 @@ fit2df.coxphlist <- function(.data, condense=TRUE, metrics=FALSE, remove_interce
 }
 
 
-# #' Extract \code{stanfit} model fit results to dataframe: \code{finalfit} model
-# #' extracters
-# #'
-# #' \code{fit2df.stanfit} is the model extract method for our standard Bayesian
-# #' hierarchical binomial logistic regression models. These models will be fully
-# #' documented separately. However this should work for a single or multilevel
-# #' Bayesian logistic regression done in Stan, as long as the fixed effects are
-# #' specified in the parameters block as a vector named \code{beta}, of length
-# #' \code{P}, where \code{P} is the number of fixed effect parameters. e.g.
-# #' parameters{ vector[P] beta; }
-# #'
-# #' @rdname fit2df
-# #' @method fit2df stanfit
-# #' @export
-# #'
-# fit2df.stanfit = function(.data, condense=TRUE, metrics=FALSE, remove_intercept=TRUE,
-# 													explanatory_name = "explanatory",
-# 													estimate_name = "OR",
-# 													estimate_suffix = "",
-# 													p_name = "p",
-# 													digits=c(2,2,3),
-# 													confint_sep = "-", ...){
-# 	args = list(...)
-#
-# 	if(is.null(args$X)) stop("Must include design matrix from Stan procedure, e.g. X=X")
-#
-# 	df.out = extract_fit(.data=.data, explanatory_name=explanatory_name,
-# 											 estimate_name=estimate_name, estimate_suffix=estimate_suffix,
-# 											 p_name=p_name, digits=digits, X=args$X)
-#
-# 	if (condense==TRUE){
-# 		df.out = condense_fit(df.out, explanatory_name=explanatory_name,
-# 													estimate_name=estimate_name, estimate_suffix=estimate_suffix,
-# 													p_name=p_name, digits=digits, confint_sep=confint_sep)
-# 	}
-#
-# 	if (remove_intercept==TRUE){
-# 		df.out = remove_intercept(df.out)
-# 	}
-#
-# 	# Extract model metrics
-# 	## This needs an ff_metrics() method
-# 	if (metrics==TRUE){
-# 		# n_data = dim(x$data)[1] # no equivalent here
-# 		n_model = dim(args$X)[1]
-# 		# aic = round(x$aic, 1) # add WAIC later?
-# 		# auc = round(roc(x$y, x$fitted)$auc[1], 3) # Add predicted mu later?
-# 		metrics.out = paste0(
-# 			#	"Number in dataframe = ", n_data,
-# 			", Number in model = ", n_model)
-# 		#	", Missing = ", n_data-n_model,
-# 		#	", AIC = ", aic,
-# 		#	", C-statistic = ", auc)
-# 	}
-#
-# 	if (metrics==TRUE){
-# 		return(list(df.out, metrics.out))
-# 	} else {
-# 		return(df.out)
-# 	}
-# 	return(df.out)
-# }
+#' Extract \code{cmprsk::crr} model fit results to dataframe: \code{finalfit} model extracters
+#'
+#' \code{fit2df.crr} is the model extract method for \code{cmprsk::\link[cmprsk]{crr}}.
+#'
+#' @rdname fit2df
+#' @method fit2df crr
+#' @export
+#'
+fit2df.crr <- function(.data, condense=TRUE, metrics=FALSE,
+												 explanatory_name = "explanatory",
+												 estimate_name = "HR",
+												 estimate_suffix = "",
+												 p_name = "p",
+												 digits=c(2,2,3),
+												 confint_sep = "-", ...){
+	
+	df.out = extract_fit(.data=.data, explanatory_name=explanatory_name,
+											 estimate_name=estimate_name, estimate_suffix=estimate_suffix,
+											 p_name=p_name)
+	
+	if (condense==TRUE){
+		df.out = condense_fit(.data=df.out, explanatory_name=explanatory_name,
+													estimate_name=estimate_name, estimate_suffix=estimate_suffix,
+													p_name=p_name, digits=digits, confint_sep=confint_sep)
+	}
+	# Extract model metrics
+	if (metrics==TRUE){
+		metrics.out = ff_metrics(.data)
+		return(list(df.out, metrics.out))
+	} else {
+		return(df.out)
+	}
+}
+
+#' Extract \code{crruni} and \code{crrmulti} model fit results to dataframe:
+#' \code{finalfit} model extracters
+#'
+#' \code{fit2df.crr} is the model extract method for
+#' \code{crruni} and \code{crrmulti}.
+#'
+#' @rdname fit2df
+#' @method fit2df crrlist
+#' @export
+#' 
+fit2df.crrlist <- function(.data, condense=TRUE, metrics=FALSE,
+											 explanatory_name = "explanatory",
+											 estimate_name = "HR",
+											 estimate_suffix = "",
+											 p_name = "p",
+											 digits=c(2,2,3),
+											 confint_sep = "-", ...){
+	
+	df.out = .data %>% 
+		purrr::map_dfr(extract_fit, explanatory_name=explanatory_name,
+									 estimate_name=estimate_name, estimate_suffix=estimate_suffix,
+									 p_name=p_name, digits=digits)
+
+	
+	if (condense==TRUE){
+		df.out = condense_fit(.data=df.out, explanatory_name=explanatory_name,
+													estimate_name=estimate_name, estimate_suffix=estimate_suffix,
+													p_name=p_name, digits=digits, confint_sep=confint_sep)
+	}
+	# Extract model metrics
+	if (metrics==TRUE){
+		metrics.out = ff_metrics(.data)
+		return(list(df.out, metrics.out))
+	} else {
+		return(df.out)
+	}
+}
+
+#' Extract \code{stanfit} model fit results to dataframe: \code{finalfit} model
+#' extracters
+#'
+#' \code{fit2df.stanfit} is the model extract method for our standard Bayesian
+#' hierarchical binomial logistic regression models. These models will be fully
+#' documented separately. However this should work for a single or multilevel
+#' Bayesian logistic regression done in Stan, as long as the fixed effects are
+#' specified in the parameters block as a vector named \code{beta}, of length
+#' \code{P}, where \code{P} is the number of fixed effect parameters. e.g.
+#' parameters{ vector[P] beta; }
+#'
+#' @rdname fit2df
+#' @method fit2df stanfit
+#' @export
+#'
+fit2df.stanfit = function(.data, condense=TRUE, metrics=FALSE, remove_intercept=TRUE,
+													explanatory_name = "explanatory",
+													estimate_name = "OR",
+													estimate_suffix = "",
+													p_name = "p",
+													digits=c(2,2,3),
+													confint_sep = "-", ...){
+	args = list(...)
+
+	if(is.null(args$X)) stop("Must include design matrix from Stan procedure, e.g. X=X")
+
+	df.out = extract_fit(.data=.data, explanatory_name=explanatory_name,
+											 estimate_name=estimate_name, estimate_suffix=estimate_suffix,
+											 p_name=p_name, digits=digits, X=args$X)
+
+	if (condense==TRUE){
+		df.out = condense_fit(df.out, explanatory_name=explanatory_name,
+													estimate_name=estimate_name, estimate_suffix=estimate_suffix,
+													p_name=p_name, digits=digits, confint_sep=confint_sep)
+	}
+
+	if (remove_intercept==TRUE){
+		df.out = remove_intercept(df.out)
+	}
+
+	# Extract model metrics
+	## This needs an ff_metrics() method
+	if (metrics==TRUE){
+		# n_data = dim(x$data)[1] # no equivalent here
+		n_model = dim(args$X)[1]
+		# aic = round(x$aic, 1) # add WAIC later?
+		# auc = round(roc(x$y, x$fitted)$auc[1], 3) # Add predicted mu later?
+		metrics.out = paste0(
+			#	"Number in dataframe = ", n_data,
+			", Number in model = ", n_model)
+		#	", Missing = ", n_data-n_model,
+		#	", AIC = ", aic,
+		#	", C-statistic = ", auc)
+	}
+
+	if (metrics==TRUE){
+		return(list(df.out, metrics.out))
+	} else {
+		return(df.out)
+	}
+	return(df.out)
+}
