@@ -160,7 +160,18 @@ test_that("summary_factorlist gives dataframe", {
 })
 
 
+context("summary_factorlist function with geometric mean")
+library(finalfit)
 
+test_that("summary_factorlist gives dataframe", {
+	expect_is(summary_factorlist(colon_s, "extent.factor", c("age.factor", "age"),
+															 cont="geometric"), "data.frame")
+})
+
+test_that("summary_factorlist gives error when variable contains zero and geometric mean called", {
+	expect_error(summary_factorlist(colon_s, "extent.factor", c("age.factor", "nodes"),
+															 cont="geometric"))
+})
 
 
 context("summary_factorlist function with median and dep label")
@@ -202,6 +213,7 @@ test_that("summary_factorlist gives dataframe", {
 
 
 
+
 context("summary_factorlist function with survival")
 library(finalfit)
 
